@@ -16,12 +16,13 @@ from puke.Yak import *
 from puke.VirtualEnv import *
 import puke.System
 import puke.FileSystem
+import puke.Utils
 
 
 VERSION = 0.1
 __all__ = [
-            "main", "VERSION", "Error", "FileList", "Sed", "console", "Env", "Require", "Yak", "VirtualEnv", "System", "FileSystem",
-            "combine", "sh", "minify", "jslint", "jsdoc", "patch", "prompt", "deepcopy", "stats", "pack", "unpack", "hsizeof"
+            "main", "VERSION", "Error", "FileList", "Sed", "Env", "Require", "Yak", "VirtualEnv", "System", "FileSystem", "Utils",
+            "combine", "sh", "minify", "jslint", "jsdoc", "patch", "prompt", "deepcopy", "stats", "pack", "unpack", "hsizeof", "console"
          ]
 
 
